==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionNumberInputInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionNumberInputInfoDescription } from "./ToolActionNumberInputInfoDescription";
/**
 * @hidden
 */
export let ToolActionNumberInputInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionNumberInputInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionNumberInputInfoDescriptionMetadata.a == null) {
                ToolActionNumberInputInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionNumberInputInfoDescriptionMetadata.c(ToolActionNumberInputInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionNumberInputInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionNumberInputInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("Value", "Number:double");
        }
        static d(a) {
            ToolActionNumberInputInfoDescriptionMetadata.b(a);
            a.ad("ToolActionNumberInputInfo", () => new ToolActionNumberInputInfoDescription());
            a.ac("ToolActionNumberInputInfo", ToolActionNumberInputInfoDescriptionMetadata.a);
        }
    }
    ToolActionNumberInputInfoDescriptionMetadata.$t = markType(ToolActionNumberInputInfoDescriptionMetadata, 'ToolActionNumberInputInfoDescriptionMetadata');
    ToolActionNumberInputInfoDescriptionMetadata.a = null;
    return ToolActionNumberInputInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionNumberInputInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionNumberInputInfoDescription } from "./ToolActionNumberInputInfoDescription";
/**
 * @hidden
 */
export let ToolActionNumberInputInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionNumberInputInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionNumberInputInfoDescriptionMetadata.a == null) {
                ToolActionNumberInputInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionNumberInputInfoDescriptionMetadata.c(ToolActionNumberInputInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionNumberInputInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionNumberInputInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("Value", "Number:double");
        }
        static d(a) {
            ToolActionNumberInputInfoDescriptionMetadata.b(a);
            a.ae("ToolActionNumberInputInfo", () => new ToolActionNumberInputInfoDescription());
            a.ad("ToolActionNumberInputInfo", ToolActionNumberInputInfoDescriptionMetadata.a);
        }
    }
    ToolActionNumberInputInfoDescriptionMetadata.$t = markType(ToolActionNumberInputInfoDescriptionMetadata, 'ToolActionNumberInputInfoDescriptionMetadata');
    ToolActionNumberInputInfoDescriptionMetadata.a = null;
    return ToolActionNumberInputInfoDescriptionMetadata;
})();
